
# CHANGES

## v0.0.2 - 2013/08/07

  * Include image and summary in pulled data.

## v0.0.1 - 2013/04/03

  * initial release
  * very basic initial code - only fetches persons and only stores names.
